@@ -22,8 +22,6 @@ def md5it(f, MAXSIZE, VERBOSITY=0, PROFILES=False):
         if bytesread > MAXSIZE:
             if VERBOSITY:
                 hashval = h.hexdigest()
-                if PROFILES:
-                    hashval = hashval[:4]
                 print "Stopping processing of %s because we've already hashed max-size (%d) bytes of it.  (The result will be %s.)" % (f, MAXSIZE, hashval)
             break
 
@@ -43,9 +41,13 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILE
     # d2 = { (dev, ino): [fname] or [] } # also for dirs, with empty [fname]
 
     tempd = fileutil.NamedTemporaryDirectory()
-    d1 = anydbm.open(os.path.join(tempd.name, TMPDB1FNAME), "n")
+    db1fname = os.path.join(tempd.name, TMPDB1FNAME)
+    d1 = anydbm.open(db1fname, "n")
     tempd.register_file(d1)
-    d2 = anydbm.open(os.path.join(tempd.name, TMPDB2FNAME), "n")
+    fileutil.remove_if_possible(db1fname)
+    db2fname = os.path.join(tempd.name, TMPDB2FNAME)
+    d2 = anydbm.open(db2fname, "n")
+    fileutil.remove_if_possible(db2fname)
     tempd.register_file(d2)
     try:
         return _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFILES, NOFOLLOWSYMLINKS, DIRS, WINDOWS, d1, d2)
@@ -145,9 +147,9 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
             if (VERBOSITY > 2) or (VERBOSITY > 1 and len(thed1set) > 1):
                 print "about to compare %d elements of size class %d" % (len(thed1set), size)
             # on Windows and Cygwin -- idx is unique and the length of [ fname ] is always 1:
-            # d3 = { k: md5hash, v: { k: idx, v: [ fname ] } }
+            # d3 = { k: md5hash, v: { k: idx, v: set( fname ) } }
             # on other platforms:
-            # d3 = { k: md5hash, v: { k: devino, v: [ fname ] } }
+            # d3 = { k: md5hash, v: { k: devino, v: set( fname ) } }
             d3 = {}
             if WINDOWS:
                 idx = 0
@@ -158,7 +160,7 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
                     md5h = None
 
                 if WINDOWS:
-                    fnames = [fname_or_devino]
+                    fnames = set([fname_or_devino])
                 else:
                     fnames = loads(d2[fname_or_devino])
 
@@ -174,7 +176,7 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
                     break
 
                 if PROFILES:
-                    print "%s:%s" % (md5h[:4], next_power_of_k(size, 2))
+                    print "%s:%s" % (md5h, size)
 
                 d4 = d3.setdefault(md5h, {})
                 if WINDOWS:
@@ -194,7 +196,7 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
                         d4[d4k] = d4v
                     for (iterdevino, iterfnames) in d4.iteritems():
                         if PROFILES:
-                            print "identical; md5: %s, size: %s" % (md5h[:4], next_power_of_k(size, 2),)
+                            print "identical; md5: %s, size: %s" % (md5h, size)
                         else:
                             print "md5: %s, size: %s, fnames: %s" % (md5h, size, iterfnames,)
                         if HARDLINKEM or DELETEEM:
@@ -209,7 +211,7 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, MAXSIZE, PROFIL
                 elif len(d4) > 2:
                     # More collisions.  Print out the new one.
                     if PROFILES:
-                        print "identical; md5: %s, size: %s" % (md5h[:4], next_power_of_k(size, 2),)
+                        print "identical; md5: %s, size: %s" % (md5h, size)
                     else:
                         print "md5: %s, size: %s, fnames: %s" % (md5h, size, fnames,)
                     if HARDLINKEM or DELETEEM:
